@@ -1,9 +1,9 @@
 /*
- * "$Id: aix.c 749 2007-01-14 20:55:33Z mike $"
+ * "$Id: aix.c 839 2010-12-30 18:41:50Z mike $"
  *
  *   AIX package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2007 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -189,8 +189,9 @@ make_aix(const char     *prodname,	/* I - Product short name */
     {
       case 'c' :
       case 'f' :
-          if (!strncmp(file->dst, "/usr/", 5) ||
-	      !strncmp(file->dst, "/opt/", 5))
+          if (!strncmp(file->dst, "/export/", 8) ||
+	      !strncmp(file->dst, "/opt/", 5) ||
+	      !strncmp(file->dst, "/usr/", 5))
             snprintf(filename, sizeof(filename), "%s/%s%s", directory, prodname,
 	             file->dst);
 	  else
@@ -235,10 +236,12 @@ make_aix(const char     *prodname,	/* I - Product short name */
 	  }
           break;
       case 'd' :
-          if (!strcmp(file->dst, "/usr") ||
-	      !strncmp(file->dst, "/usr/", 5) ||
+          if (!strcmp(file->dst, "/export") ||
+	      !strncmp(file->dst, "/export/", 8) ||
 	      !strcmp(file->dst, "/opt") ||
-	      !strncmp(file->dst, "/opt/", 5))
+	      !strncmp(file->dst, "/opt/", 5) ||
+	      !strcmp(file->dst, "/usr") ||
+	      !strncmp(file->dst, "/usr/", 5))
             snprintf(filename, sizeof(filename), "%s/%s%s", directory, prodname,
 	             file->dst);
 	  else
@@ -252,8 +255,9 @@ make_aix(const char     *prodname,	/* I - Product short name */
 			 grp ? grp->gr_gid : 0);
           break;
       case 'l' :
-          if (!strncmp(file->dst, "/usr/", 5) ||
-	      !strncmp(file->dst, "/opt/", 5))
+          if (!strncmp(file->dst, "/export/", 8) ||
+	      !strncmp(file->dst, "/opt/", 5) ||
+	      !strncmp(file->dst, "/usr/", 5))
             snprintf(filename, sizeof(filename), "%s/%s%s", directory, prodname,
 	             file->dst);
 	  else
@@ -291,11 +295,13 @@ make_aix(const char     *prodname,	/* I - Product short name */
     if (Verbosity)
       puts("Removing temporary distribution files...");
 
-    run_command(NULL, "/bin/rm -rf %s/%s", directory, prodname);
+    snprintf(filename, sizeof(filename), "%s/%s", directory, prodname);
+    unlink_directory(filename);
 
     for (i = 0; i < (sizeof(files) / sizeof(files[0])); i ++)
     {
-      snprintf(filename, sizeof(filename), "%s/%s.%s", directory, prodname, files[i]);
+      snprintf(filename, sizeof(filename), "%s/%s.%s", directory, prodname,
+               files[i]);
       unlink(filename);
     }
 
@@ -720,8 +726,7 @@ write_liblpp(const char     *prodname,	/* I - Product short name */
     fclose(fp);
 
    /*
-    * Write the product.unpre_i file for installp (note, despite the name,
-    * unpre_i is the post-removal script...)
+    * Write the product.unpre_i file for installp...
     */
 
     if (Verbosity > 1)
@@ -742,14 +747,13 @@ write_liblpp(const char     *prodname,	/* I - Product short name */
     fputs("# " EPM_VERSION "\n", fp);
 
     for (c = dist->commands, i = dist->num_commands; i > 0; i --, c ++)
-      if (c->type == COMMAND_POST_REMOVE && c->subpackage == subpackage)
+      if (c->type == COMMAND_PRE_REMOVE && c->subpackage == subpackage)
 	fprintf(fp, "%s\n", c->command);
 
     fclose(fp);
 
    /*
-    * Write the product.unpost_i file for installp (note, despite the name,
-    * unpost_i is the pre-removal script...)
+    * Write the product.unpost_i file for installp...
     */
 
     if (Verbosity > 1)
@@ -770,7 +774,7 @@ write_liblpp(const char     *prodname,	/* I - Product short name */
     fputs("# " EPM_VERSION "\n", fp);
 
     for (c = dist->commands, i = dist->num_commands; i > 0; i --, c ++)
-     if (c->type == COMMAND_PRE_REMOVE && c->subpackage == subpackage)
+     if (c->type == COMMAND_POST_REMOVE && c->subpackage == subpackage)
 	fprintf(fp, "%s\n", c->command);
 
     fclose(fp);
@@ -942,5 +946,5 @@ write_liblpp(const char     *prodname,	/* I - Product short name */
 
 
 /*
- * End of "$Id: aix.c 749 2007-01-14 20:55:33Z mike $".
+ * End of "$Id: aix.c 839 2010-12-30 18:41:50Z mike $".
  */
