@@ -1,9 +1,9 @@
 /*
- * "$Id: deb.c 697 2006-08-17 21:00:25Z mike $"
+ * "$Id: deb.c 833 2010-12-30 00:00:50Z mike $"
  *
  *   Debian package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2006 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -589,7 +589,8 @@ make_subpackage(const char     *prodname,
     if (Verbosity)
       printf("Removing temporary %s distribution files...\n", name);
 
-    run_command(NULL, "/bin/rm -rf %s/%s", directory, name);
+    snprintf(filename, sizeof(filename), "%s/%s", directory, name);
+    unlink_directory(filename);
   }
 
   return (0);
@@ -597,5 +598,5 @@ make_subpackage(const char     *prodname,
 
 
 /*
- * End of "$Id: deb.c 697 2006-08-17 21:00:25Z mike $".
+ * End of "$Id: deb.c 833 2010-12-30 00:00:50Z mike $".
  */
