@@ -1,9 +1,9 @@
 /*
- * "$Id: dist.c 733 2006-11-30 21:59:27Z mike $"
+ * "$Id: dist.c 843 2010-12-31 02:18:18Z mike $"
  *
  *   Distribution functions for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2006 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -17,30 +17,32 @@
  *
  * Contents:
  *
- *   add_command()      - Add a command to the distribution...
- *   add_depend()       - Add a dependency to the distribution...
- *   add_description()  - Add a description to the distribution.
- *   add_file()         - Add a file to the distribution.
- *   add_subpackage()   - Add a subpackage to the distribution.
- *   find_subpackage()  - Find a subpackage in the distribution.
- *   free_dist()        - Free memory used by a distribution.
- *   getoption()        - Get an option from a file.
- *   get_platform()     - Get the operating system information...
- *   get_runlevels()    - Get the run levels for the specified init script.
- *   get_start()        - Get the start number for an init script.
- *   get_stop()         - Get the stop number for an init script.
- *   new_dist()         - Create a new, empty software distribution.
- *   read_dist()        - Read a software distribution.
- *   sort_dist_files()  - Sort the files in the distribution.
- *   write_dist()       - Write a distribution list file...
- *   compare_files()    - Compare the destination filenames.
- *   expand_name()      - Expand a filename with environment variables.
- *   get_file()         - Read a file into a string...
- *   get_inline()       - Read inline lines into a string...
- *   get_line()         - Get a line from a file, filtering for uname lines...
- *   get_string()       - Get a delimited string from a line.
- *   patmatch()         - Pattern matching...
- *   sort_subpackages() - Compare two subpackage names.
+ *   add_command()         - Add a command to the distribution...
+ *   add_depend()          - Add a dependency to the distribution...
+ *   add_description()     - Add a description to the distribution.
+ *   add_file()            - Add a file to the distribution.
+ *   add_subpackage()      - Add a subpackage to the distribution.
+ *   find_subpackage()     - Find a subpackage in the distribution.
+ *   free_dist()           - Free memory used by a distribution.
+ *   getoption()           - Get an option from a file.
+ *   get_platform()        - Get the operating system information...
+ *   get_runlevels()       - Get the run levels for the specified init script.
+ *   get_start()           - Get the start number for an init script.
+ *   get_stop()            - Get the stop number for an init script.
+ *   new_dist()            - Create a new, empty software distribution.
+ *   read_dist()           - Read a software distribution.
+ *   sort_dist_files()     - Sort the files in the distribution.
+ *   write_dist()          - Write a distribution list file...
+ *   compare_files()       - Compare the destination filenames.
+ *   expand_name()         - Expand a filename with environment variables.
+ *   get_file()            - Read a file into a string...
+ *   get_inline()          - Read inline lines into a string...
+ *   get_line()            - Get a line from a file, filtering for uname
+ *                           lines...
+ *   get_string()          - Get a delimited string from a line.
+ *   patmatch()            - Pattern matching...
+ *   sort_subpackages()    - Compare two subpackage names.
+ *   update_architecture() - Normalize the machine architecture name.
  */
 
 /*
@@ -65,7 +67,7 @@ extern int	gethostname(char *, int);
  */
 
 static int	compare_files(const file_t *f0, const file_t *f1);
-static void	expand_name(char *buffer, char *name, size_t bufsize);
+static void	expand_name(char *buffer, char *name, size_t bufsize, int warn);
 static char	*get_file(const char *filename, char *buffer, size_t size);
 static char	*get_inline(const char *term, FILE *fp, char *buffer,
 		            size_t size);
@@ -75,6 +77,7 @@ static char	*get_line(char *buffer, int size, FILE *fp,
 static char	*get_string(char **src, char *dst, size_t dstsize);
 static int	patmatch(const char *, const char *);
 static int	sort_subpackages(char **a, char **b);
+static void	update_architecture(char *buffer, size_t bufsize);
 
 
 /*
@@ -83,10 +86,11 @@ static int	sort_subpackages(char **a, char **b);
 
 #define SKIP_SYSTEM	1		/* Not the right system */
 #define SKIP_FORMAT	2		/* Not the right format */
-#define SKIP_IF		4		/* Set if the current #if was not satisfied */
-#define SKIP_IFACTIVE	8		/* Set if we're in an #if */
-#define SKIP_IFSAT	16		/* Set if an #if statement has been satisfied */
-#define SKIP_MASK	7		/* Bits to look at */
+#define SKIP_ARCH	4		/* Not the right architecture */
+#define SKIP_IF		8		/* Set if the current #if was not satisfied */
+#define SKIP_IFACTIVE	16		/* Set if we're in an #if */
+#define SKIP_IFSAT	32		/* Set if an #if statement has been satisfied */
+#define SKIP_MASK	15		/* Bits to look at */
 
 
 /*
@@ -98,13 +102,14 @@ add_command(dist_t     *dist,		/* I - Distribution */
             FILE       *fp,		/* I - Distribution file */
             int        type,		/* I - Command type */
 	    const char *command,	/* I - Command string */
-	    const char *subpkg)		/* I - Subpackage */
+	    const char *subpkg,		/* I - Subpackage */
+            const char *section)	/* I - Literal text section */
 {
   command_t	*temp;			/* New command */
   char		buf[16384];		/* File import buffer */
 
 
-  if (strncmp(command, "<<", 2) == 0)
+  if (!strncmp(command, "<<", 2))
   {
     for (command += 2; isspace(*command & 255); command ++);
 
@@ -117,7 +122,7 @@ add_command(dist_t     *dist,		/* I - Distribution */
     command = get_file(command, buf, sizeof(buf));
   }
 
-  if (command == NULL)
+  if (!command)
     return;
 
   if (dist->num_commands == 0)
@@ -125,7 +130,7 @@ add_command(dist_t     *dist,		/* I - Distribution */
   else
     temp = realloc(dist->commands, (dist->num_commands + 1) * sizeof(command_t));
 
-  if (temp == NULL)
+  if (!temp)
   {
     perror("epm: Out of memory allocating a command");
     return;
@@ -135,13 +140,24 @@ add_command(dist_t     *dist,		/* I - Distribution */
   temp             += dist->num_commands;
   temp->type       = type;
   temp->command    = strdup(command);
-  temp->subpackage = subpkg;
-
-  if (temp->command == NULL)
+  if (!temp->command)
   {
     perror("epm: Out of memory duplicating a command string");
     return;
   }
+  temp->subpackage = subpkg;
+  if (section && *section)
+  {
+    temp->section = strdup(section);
+    if (!temp->section)
+    {
+      perror("epm: Out of memory duplicating a literal section");
+      free(temp->command);
+      return;
+    }
+  }
+  else
+    temp->section = NULL;
 
   dist->num_commands ++;
 }
@@ -296,7 +312,7 @@ add_description(dist_t     *dist,	/* I - Distribution */
   char		buf[16384];		/* File import buffer */
 
 
-  if (strncmp(description, "<<", 2) == 0)
+  if (!strncmp(description, "<<", 2))
   {
     for (description += 2; isspace(*description & 255); description ++);
 
@@ -454,7 +470,11 @@ free_dist(dist_t *dist)			/* I - Distribution to free */
     free(dist->subpackages);
 
   for (i = 0; i < dist->num_commands; i ++)
+  {
     free(dist->commands[i].command);
+    if (dist->commands[i].section)
+      free(dist->commands[i].section);
+  }
 
   if (dist->num_commands)
     free(dist->commands);
@@ -581,30 +601,8 @@ get_platform(struct utsname *platform)	/* O - Platform info */
   strcpy(platform->machine, "hppa");
 #elif defined(_AIX)
   strcpy(platform->machine, "powerpc");
-#elif defined(__APPLE__)
-  if (strstr(platform->machine, "86") != NULL)
-    strcpy(platform->machine, "intel");
-  else
-    strcpy(platform->machine, "powerpc");
 #else
-  for (temp = platform->machine; *temp != '\0'; temp ++)
-    if (*temp == '-' || *temp == '_')
-    {
-      strcpy(temp, temp + 1);
-      temp --;
-    }
-    else
-      *temp = tolower(*temp);
-
-  if (strstr(platform->machine, "86") != NULL)
-  {
-    if (strstr(platform->machine, "64") != NULL)
-      strcpy(platform->machine, "x86_64");
-    else
-      strcpy(platform->machine, "intel");
-  }
-  else if (strncmp(platform->machine, "sun", 3) == 0)
-    strcpy(platform->machine, "sparc");
+  update_architecture(platform->machine, sizeof(platform->machine));
 #endif /* __sgi */
 
 #ifdef _AIX
@@ -654,8 +652,7 @@ get_platform(struct utsname *platform)	/* O - Platform info */
   * Digital UNIX a.k.a. Compaq Tru64 UNIX...
   */
 
-  if (strcmp(platform->sysname, "sunos") == 0 &&
-      platform->release[0] >= '5')
+  if (!strcmp(platform->sysname, "sunos") && platform->release[0] >= '5')
   {
     strcpy(platform->sysname, "solaris");
 
@@ -673,9 +670,9 @@ get_platform(struct utsname *platform)	/* O - Platform info */
       *temp = '\0';
     }
   }
-  else if (strcmp(platform->sysname, "osf1") == 0)
+  else if (!strcmp(platform->sysname, "osf1"))
     strcpy(platform->sysname, "tru64"); /* AKA Digital UNIX */
-  else if (strcmp(platform->sysname, "irix64") == 0)
+  else if (!strcmp(platform->sysname, "irix64"))
     strcpy(platform->sysname, "irix"); /* IRIX */
 
 #ifdef DEBUG
@@ -829,7 +826,8 @@ read_dist(const char     *filename,	/* I - Main distribution list file */
       */
 
       line[0] = buf[0]; /* Don't expand initial $ */
-      expand_name(line + 1, buf + 1, sizeof(line) - 1);
+      expand_name(line + 1, buf + 1, sizeof(line) - 1,
+                  strncmp(buf, "%if", 3) || strncmp(buf, "%elseif", 7));
 
      /*
       * Check line for config stuff...
@@ -848,7 +846,7 @@ read_dist(const char     *filename,	/* I - Main distribution list file */
         * Process directive...
         */
 
-	if (strcmp(line, "%include") == 0)
+	if (!strcmp(line, "%include"))
 	{
 	  listlevel ++;
 
@@ -859,72 +857,87 @@ read_dist(const char     *filename,	/* I - Main distribution list file */
 	    listlevel --;
 	  }
 	}
-	else if (strcmp(line, "%description") == 0)
+	else if (!strcmp(line, "%description"))
 	  add_description(dist, listfiles[listlevel], temp, subpkg);
-	else if (strcmp(line, "%preinstall") == 0)
+	else if (!strcmp(line, "%preinstall"))
           add_command(dist, listfiles[listlevel], COMMAND_PRE_INSTALL, temp,
-	              subpkg);
-	else if (strcmp(line, "%install") == 0 ||
-	         strcmp(line, "%postinstall") == 0)
+	              subpkg, NULL);
+	else if (!strcmp(line, "%install") || !strcmp(line, "%postinstall"))
           add_command(dist, listfiles[listlevel], COMMAND_POST_INSTALL, temp,
-	              subpkg);
-	else if (strcmp(line, "%remove") == 0 ||
-	         strcmp(line, "%preremove") == 0)
+	              subpkg, NULL);
+	else if (!strcmp(line, "%remove") || !strcmp(line, "%preremove"))
           add_command(dist, listfiles[listlevel], COMMAND_PRE_REMOVE, temp,
-	              subpkg);
-	else if (strcmp(line, "%postremove") == 0)
+	              subpkg, NULL);
+	else if (!strcmp(line, "%postremove"))
           add_command(dist, listfiles[listlevel], COMMAND_POST_REMOVE, temp,
-	              subpkg);
-	else if (strcmp(line, "%prepatch") == 0)
+	              subpkg, NULL);
+	else if (!strcmp(line, "%prepatch"))
           add_command(dist, listfiles[listlevel], COMMAND_PRE_PATCH, temp,
-	              subpkg);
-	else if (strcmp(line, "%patch") == 0 ||
-	         strcmp(line, "%postpatch") == 0)
+	              subpkg, NULL);
+	else if (!strcmp(line, "%patch") || !strcmp(line, "%postpatch"))
           add_command(dist, listfiles[listlevel], COMMAND_POST_PATCH, temp,
-	              subpkg);
-        else if (strcmp(line, "%product") == 0)
+	              subpkg, NULL);
+	else if (!strncmp(line, "%literal(", 9))
+        {
+          char	*ptr,			/* Pointer to parenthesis */
+		*section;		/* Section for literal text */
+
+
+	  section = line + 9;
+	  if ((ptr = strchr(section, ')')) != NULL)
+	  {
+	    *ptr = '\0';
+
+	    add_command(dist, listfiles[listlevel], COMMAND_LITERAL, temp,
+			subpkg, section);
+	  }
+	  else
+	    fputs("epm: Ignoring bad %literal(section) line in list file.\n",
+		  stderr);
+        }
+        else if (!strcmp(line, "%product"))
 	{
           if (!dist->product[0])
             strcpy(dist->product, temp);
 	  else
 	    fputs("epm: Ignoring %product line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%copyright") == 0)
+	else if (!strcmp(line, "%copyright"))
 	{
           if (!dist->copyright[0])
             strcpy(dist->copyright, temp);
 	  else
 	    fputs("epm: Ignoring %copyright line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%vendor") == 0)
+	else if (!strcmp(line, "%vendor"))
 	{
           if (!dist->vendor[0])
             strcpy(dist->vendor, temp);
 	  else
 	    fputs("epm: Ignoring %vendor line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%packager") == 0)
+	else if (!strcmp(line, "%packager"))
 	{
           if (!dist->packager[0])
             strcpy(dist->packager, temp);
 	  else
 	    fputs("epm: Ignoring %packager line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%license") == 0)
+	else if (!strcmp(line, "%license"))
 	{
           if (!dist->license[0])
             strcpy(dist->license, temp);
 	  else
 	    fputs("epm: Ignoring %license line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%readme") == 0)
+	else if (!strcmp(line, "%readme"))
 	{
           if (!dist->readme[0])
             strcpy(dist->readme, temp);
 	  else
 	    fputs("epm: Ignoring %readme line in list file.\n", stderr);
 	}
-	else if (strcmp(line, "%subpackage") == 0)
+	else if (!strcmp(line, "%subpackage"))
 	{
 	  subpkg = find_subpackage(dist, temp);
 	}
@@ -960,18 +973,18 @@ read_dist(const char     *filename,	/* I - Main distribution list file */
 	    }
 	  }
 	}
-	else if (strcmp(line, "%release") == 0)
+	else if (!strcmp(line, "%release"))
 	{
 	  strlcpy(dist->release, temp, sizeof(dist->release));
 	  dist->vernumber += atoi(temp);
 	}
-	else if (strcmp(line, "%incompat") == 0)
+	else if (!strcmp(line, "%incompat"))
 	  add_depend(dist, DEPEND_INCOMPAT, temp, subpkg);
-	else if (strcmp(line, "%provides") == 0)
+	else if (!strcmp(line, "%provides"))
 	  add_depend(dist, DEPEND_PROVIDES, temp, subpkg);
-	else if (strcmp(line, "%replaces") == 0)
+	else if (!strcmp(line, "%replaces"))
 	  add_depend(dist, DEPEND_REPLACES, temp, subpkg);
-	else if (strcmp(line, "%requires") == 0)
+	else if (!strcmp(line, "%requires"))
 	  add_depend(dist, DEPEND_REQUIRES, temp, subpkg);
 	else
 	{
@@ -1072,10 +1085,10 @@ read_dist(const char     *filename,	/* I - Main distribution list file */
 	}
 
 #ifdef __osf__ /* Remap group "sys" to "system" */
-        if (strcmp(group, "sys") == 0)
+        if (!strcmp(group, "sys"))
 	  strcpy(group, "system");
 #elif defined(__linux) /* Remap group "sys" to "root" */
-        if (strcmp(group, "sys") == 0)
+        if (!strcmp(group, "sys"))
 	  strcpy(group, "root");
 #endif /* __osf__ */
 
@@ -1439,10 +1452,12 @@ compare_files(const file_t *f0,		/* I - First file */
 static void
 expand_name(char   *buffer,		/* O - Output string */
             char   *name,		/* I - Input string */
-	    size_t bufsize)		/* I - Size of output string */
+	    size_t bufsize,		/* I - Size of output string */
+	    int    warn)		/* I - Warn when not set? */
 {
   char	var[255],			/* Environment variable name */
-	*varptr;			/* Current position in name */
+	*varptr,			/* Current position in name */
+	delim;				/* Delimiter character */
 
 
   bufsize --;
@@ -1461,16 +1476,19 @@ expand_name(char   *buffer,		/* O - Output string */
 	bufsize --;
 	continue;
       }
-      else if (*name == '{')
+      else if (*name == '{' || *name == '(')
       {
        /*
         * Bracketed variable name...
 	*/
 
-	for (varptr = var, name ++; *name != '}' && *name != '\0';)
-          *varptr++ = *name++;
+        delim = *name == '{' ? '}' : ')';
 
-        if (*name == '}')
+	for (varptr = var, name ++; *name != delim && *name; name ++)
+          if (varptr < (var + sizeof(var) - 1))
+	    *varptr++ = *name;
+
+        if (*name == delim)
 	  name ++;
       }
       else
@@ -1479,8 +1497,9 @@ expand_name(char   *buffer,		/* O - Output string */
         * Unbracketed variable name...
 	*/
 
-	for (varptr = var; strchr("/ \t\r\n-", *name) == NULL && *name != '\0';)
-          *varptr++ = *name++;
+	for (varptr = var; !strchr("/ \t\r\n-", *name) && *name; name ++)
+          if (varptr < (var + sizeof(var) - 1))
+	    *varptr++ = *name;
       }
 
       *varptr = '\0';
@@ -1491,9 +1510,14 @@ expand_name(char   *buffer,		/* O - Output string */
         bufsize -= strlen(buffer);
 	buffer  += strlen(buffer);
       }
+      else if (warn)
+        fprintf(stderr, "epm: Variable \"%s\" undefined!\n", var);
     }
     else
+    {
       *buffer++ = *name++;
+      bufsize --;
+    }
   }
 
   *buffer = '\0';
@@ -1559,7 +1583,7 @@ get_file(const char *filename,		/* I  - File to read from */
 
     expand = strdup(buffer);
 
-    expand_name(buffer, expand, size);
+    expand_name(buffer, expand, size, 1);
 
     free(expand);
   }
@@ -1594,7 +1618,7 @@ get_inline(const char *term,		/* I  - Termination string */
 
   while (fgets(bufptr, left, fp) != NULL)
   {
-    if (strncmp(bufptr, term, (size_t)termlen) == 0 && bufptr[termlen] == '\n')
+    if (!strncmp(bufptr, term, (size_t)termlen) && bufptr[termlen] == '\n')
     {
       *bufptr = '\0';
       break;
@@ -1625,7 +1649,7 @@ get_inline(const char *term,		/* I  - Termination string */
 
       expand = strdup(buffer);
 
-      expand_name(buffer, expand, size);
+      expand_name(buffer, expand, size, 1);
 
       free(expand);
     }
@@ -1673,7 +1697,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
     * See if this is a %system, %format, or conditional line...
     */
 
-    if (strncmp(buffer, "%system ", 8) == 0)
+    if (!strncmp(buffer, "%system ", 8))
     {
      /*
       * Yes, do filtering based on the OS (+version)...
@@ -1681,7 +1705,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 
       *skip &= ~SKIP_SYSTEM;
 
-      if (strcmp(buffer + 8, "all\n") != 0)
+      if (strcmp(buffer + 8, "all\n"))
       {
 	namelen = strlen(platform->sysname);
         bufptr  = buffer + 8;
@@ -1735,7 +1759,8 @@ get_line(char           *buffer,	/* I - Buffer to read into */
           if (len < namelen)
 	    match = 0;
 	  else
-	    match = strncasecmp(value, namever, strlen(value)) == 0 ? SKIP_SYSTEM : 0;
+	    match = !strncasecmp(value, namever, strlen(value)) ?
+	                SKIP_SYSTEM : 0;
 
           if (op)
 	    *skip |= match;
@@ -1744,7 +1769,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
         }
       }
     }
-    else if (strncmp(buffer, "%format ", 8) == 0)
+    else if (!strncmp(buffer, "%format ", 8))
     {
      /*
       * Yes, do filtering based on the distribution format...
@@ -1752,7 +1777,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 
       *skip &= ~SKIP_FORMAT;
 
-      if (strcmp(buffer + 8, "all\n") != 0)
+      if (strcmp(buffer + 8, "all\n"))
       {
         bufptr = buffer + 8;
 
@@ -1789,7 +1814,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 
 	  *ptr = '\0';
 
-	  match = (strcasecmp(value, format) == 0) ? SKIP_FORMAT : 0;
+	  match = !strcasecmp(value, format) ? SKIP_FORMAT : 0;
 
           if (op)
 	    *skip |= match;
@@ -1798,8 +1823,64 @@ get_line(char           *buffer,	/* I - Buffer to read into */
         }
       }
     }
-    else if (strncmp(buffer, "%ifdef ", 7) == 0 ||
-             strncmp(buffer, "%elseifdef ", 11) == 0)
+    else if (!strncmp(buffer, "%arch ", 6))
+    {
+     /*
+      * Yes, do filtering based on the current architecture...
+      */
+
+      *skip &= ~SKIP_ARCH;
+
+      if (strcmp(buffer + 6, "all\n"))
+      {
+        bufptr = buffer + 8;
+
+	while (isspace(*bufptr & 255))
+	  bufptr ++;
+
+        if (*bufptr != '!')
+	  *skip |= SKIP_ARCH;
+
+        while (*bufptr)
+	{
+	 /*
+          * Skip leading whitespace...
+	  */
+
+	  while (isspace(*bufptr & 255))
+	    bufptr ++;
+
+          if (!*bufptr)
+	    break;
+
+          if (*bufptr == '!')
+	  {
+	    op = 1;
+	    bufptr ++;
+	  }
+	  else
+	    op = 0;
+
+	  for (ptr = value;
+	       *bufptr && !isspace(*bufptr & 255) &&
+	           ptr < (value + sizeof(value) - 1);
+	       *ptr++ = *bufptr++);
+
+	  *ptr = '\0';
+
+          update_architecture(value, sizeof(value));
+
+	  match = !strcasecmp(value, platform->machine) ? SKIP_ARCH : 0;
+
+          if (op)
+	    *skip |= match;
+	  else
+	    *skip &= ~match;
+        }
+      }
+    }
+    else if (!strncmp(buffer, "%ifdef ", 7) ||
+             !strncmp(buffer, "%elseifdef ", 11))
     {
      /*
       * Yes, do filtering based on the presence of variables...
@@ -1873,8 +1954,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 	  *skip |= SKIP_IFSAT;
       }
     }
-    else if (strncmp(buffer, "%if ", 4) == 0 ||
-             strncmp(buffer, "%elseif ", 8) == 0)
+    else if (!strncmp(buffer, "%if ", 4) || !strncmp(buffer, "%elseif ", 8))
     {
      /*
       * Yes, do filtering based on the value of variables...
@@ -1948,7 +2028,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 	  *skip |= SKIP_IFSAT;
       }
     }
-    else if (strcmp(buffer, "%else\n") == 0)
+    else if (!strcmp(buffer, "%else\n"))
     {
      /*
       * Handle "else" condition of %ifdef statement...
@@ -1972,7 +2052,7 @@ get_line(char           *buffer,	/* I - Buffer to read into */
 	*skip |= SKIP_IFSAT;
       }
     }
-    else if (strcmp(buffer, "%endif\n") == 0)
+    else if (!strcmp(buffer, "%endif\n"))
     {
      /*
       * Cancel any filtering based on environment variables.
@@ -2265,5 +2345,54 @@ sort_subpackages(char **a,		/* I - First subpackage */
 
 
 /*
- * End of "$Id: dist.c 733 2006-11-30 21:59:27Z mike $".
+ * 'update_architecture()' - Normalize the machine architecture name.
+ */
+
+static void
+update_architecture(char   *buffer,	/* I - String buffer */
+                    size_t bufsize)	/* I - Size of string buffer */
+{
+  char	*temp;				/* Pointer into string buffer */
+
+
+ /*
+  * Convert the name to lowercase with no underscores or dashes.
+  */
+
+  for (temp = buffer; *temp != '\0'; temp ++)
+    if (*temp == '-' || *temp == '_')
+    {
+      char *ptr;			/* Pointer into string */
+
+      for (ptr = temp; ptr[1]; ptr ++)
+        *ptr = ptr[1];
+      *ptr = '\0';
+
+      temp --;
+    }
+    else
+      *temp = tolower(*temp);
+
+ /*
+  * Convert common synonyms to generic names...
+  */
+
+  if (strstr(buffer, "86"))
+  {
+    if (strstr(buffer, "64"))
+      strlcpy(buffer, "x86_64", bufsize);
+    else
+      strlcpy(buffer, "intel", bufsize);
+  }
+  else if (!strncmp(buffer, "arm", 3))
+    strlcpy(buffer, "arm", bufsize);
+  else if (!strncmp(buffer, "ppc", 3))
+    strlcpy(buffer, "powerpc", bufsize);
+  else if (!strncmp(buffer, "sun", 3))
+    strlcpy(buffer, "sparc", bufsize);
+}
+
+
+/*
+ * End of "$Id: dist.c 843 2010-12-31 02:18:18Z mike $".
  */
