@@ -1,9 +1,9 @@
 /*
- * "$Id: epmstring.h,v 1.5 2002/01/02 20:39:40 mike Exp $"
+ * "$Id: epmstring.h 611 2005-01-11 21:37:42Z mike $"
  *
  *   String definitions for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2002 by Easy Software Products.
+ *   Copyright 1999-2005 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,23 +41,42 @@ extern "C" {
  */
 
 #  ifndef HAVE_STRDUP
-extern char	*strdup(const char *);
+extern char	*epm_strdup(const char *);
+#    define strdup epm_strdup
 #  endif /* !HAVE_STRDUP */
 
 #  ifndef HAVE_STRCASECMP
-extern int	strcasecmp(const char *, const char *);
+extern int	epm_strcasecmp(const char *, const char *);
+#    define strcasecmp epm_strcasecmp
 #  endif /* !HAVE_STRCASECMP */
 
 #  ifndef HAVE_STRNCASECMP
-extern int	strncasecmp(const char *, const char *, size_t n);
+extern int	epm_strncasecmp(const char *, const char *, size_t n);
+#    define strncasecmp epm_strncasecmp
 #  endif /* !HAVE_STRNCASECMP */
 
+#  ifndef HAVE_STRLCAT
+extern size_t epm_strlcat(char *, const char *, size_t);
+#    define strlcat epm_strlcat
+#  endif /* !HAVE_STRLCAT */
+
+#  ifndef HAVE_STRLCPY
+extern size_t epm_strlcpy(char *, const char *, size_t);
+#    define strlcpy epm_strlcpy
+#  endif /* !HAVE_STRLCPY */
+
 #  ifndef HAVE_SNPRINTF
-extern int	snprintf(char *, size_t, const char *, ...);
+extern int	epm_snprintf(char *, size_t, const char *, ...)
+#    ifdef __GNUC__
+__attribute__ ((__format__ (__printf__, 3, 4)))
+#    endif /* __GNUC__ */
+;
+#    define snprintf epm_snprintf
 #  endif /* !HAVE_SNPRINTF */
 
 #  ifndef HAVE_VSNPRINTF
-extern int	vsnprintf(char *, size_t, const char *, va_list);
+extern int	epm_vsnprintf(char *, size_t, const char *, va_list);
+#    define vsnprintf epm_vsnprintf
 #  endif /* !HAVE_VSNPRINTF */
 
 #  ifdef __cplusplus
@@ -67,5 +86,5 @@ extern int	vsnprintf(char *, size_t, const char *, va_list);
 #endif /* !_EPM_STRING_H_ */
 
 /*
- * End of "$Id: epmstring.h,v 1.5 2002/01/02 20:39:40 mike Exp $".
+ * End of "$Id: epmstring.h 611 2005-01-11 21:37:42Z mike $".
  */
