@@ -1,9 +1,9 @@
 /*
- * "$Id: file.c 703 2006-08-29 16:43:09Z mike $"
+ * "$Id: file.c 841 2010-12-30 20:34:57Z mike $"
  *
  *   File functions for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2005 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -17,12 +17,13 @@
  *
  * Contents:
  *
- *   copy_file()      - Copy a file...
- *   make_directory() - Make a directory.
- *   make_link()      - Make a symbolic link.
- *   strip_execs()    - Strip symbols from executable files in the
- *                      distribution.
- *   unlink_package() - Delete a package file.
+ *   copy_file()        - Copy a file.
+ *   make_directory()   - Make a directory.
+ *   make_link()        - Make a symbolic link.
+ *   strip_execs()      - Strip symbols from executable files in the
+ *                        distribution.
+ *   unlink_directory() - Delete a directory and all of its nodes.
+ *   unlink_package()   - Delete a package file.
  */
 
 /*
@@ -33,7 +34,7 @@
 
 
 /*
- * 'copy_file()' - Copy a file...
+ * 'copy_file()' - Copy a file.
  */
 
 int					/* O - 0 on success, -1 on failure */
@@ -48,6 +49,7 @@ copy_file(const char *dst,		/* I - Destination file */
   char		buffer[8192];		/* Copy buffer */
   char		*slash;			/* Pointer to trailing slash */
   size_t	bytes;			/* Number of bytes read/written */
+  struct stat	srcinfo;		/* Source file information */
 
 
  /*
@@ -62,11 +64,22 @@ copy_file(const char *dst,		/* I - Destination file */
     make_directory(buffer, 0755, owner, group);
 
  /*
-  * Open files...
+  * Try doing a hard link instead of a copy...
   */
 
   unlink(dst);
 
+  if (!stat(src, &srcinfo) &&
+      (!mode || srcinfo.st_mode == mode) &&
+      (owner == (uid_t)-1 || srcinfo.st_uid == owner) &&
+      (group == (gid_t)-1 || srcinfo.st_gid == group) &&
+      !link(src, dst))
+    return (0);
+
+ /*
+  * Open files...
+  */
+
   if ((dstfile = fopen(dst, "wb")) == NULL)
   {
     fprintf(stderr, "epm: Unable to create \"%s\" -\n     %s\n", dst,
@@ -108,8 +121,10 @@ copy_file(const char *dst,		/* I - Destination file */
   fclose(srcfile);
   fclose(dstfile);
 
-  chmod(dst, mode);
-  chown(dst, owner, group);
+  if (mode)
+    chmod(dst, mode);
+  if (owner != (uid_t)-1 && group != (gid_t)-1)
+    chown(dst, owner, group);
 
   return (0);
 }
@@ -137,9 +152,11 @@ make_directory(const char *directory,	/* I - Directory */
 
       if (access(buffer, F_OK))
       {
-	mkdir(buffer, 0777);
-	chmod(buffer, mode | 0700);
-	chown(buffer, owner, group);
+	mkdir(buffer, 0755);
+	if (mode)
+          chmod(buffer, mode | 0700);
+	if (owner != (uid_t)-1 && group != (gid_t)-1)
+	  chown(buffer, owner, group);
       }
     }
 
@@ -150,9 +167,11 @@ make_directory(const char *directory,	/* I - Directory */
 
   if (access(buffer, F_OK))
   {
-    mkdir(buffer, 0777);
-    chmod(buffer, mode | 0700);
-    chown(buffer, owner, group);
+    mkdir(buffer, 0755);
+    if (mode)
+      chmod(buffer, mode | 0700);
+    if (owner != (uid_t)-1 && group != (gid_t)-1)
+      chown(buffer, owner, group);
   }
 
   return (0);
@@ -260,6 +279,105 @@ strip_execs(dist_t *dist)		/* I - Distribution to strip... */
 }
 
 
+/*
+ * 'unlink_directory()' - Delete a directory and all of its nodes.
+ */
+
+int					/* O - 0 on success, -1 on failure */
+unlink_directory(const char *directory)	/* I - Directory */
+{
+  DIR		*dir;			/* Directory */
+  DIRENT	*dent;			/* Directory entry */
+  char		filename[1024];		/* Filename */
+  struct stat	fileinfo;		/* Information on the source file */
+
+
+ /*
+  * Try opening the source directory...
+  */
+
+  if ((dir = opendir(directory)) == NULL)
+  {
+    fprintf(stderr, "epm: Unable to open directory \"%s\": %s\n", directory,
+            strerror(errno));
+
+    return (-1);
+  }
+
+ /*
+  * Read from the directory...
+  */
+
+  while ((dent = readdir(dir)) != NULL)
+  {
+   /*
+    * Skip "." and ".."...
+    */
+
+    if (!strcmp(dent->d_name, ".") || !strcmp(dent->d_name, ".."))
+      continue;
+
+   /*
+    * Get file info...
+    */
+
+    snprintf(filename, sizeof(filename), "%s/%s", directory, dent->d_name);
+
+    if (stat(filename, &fileinfo))
+    {
+      fprintf(stderr, "epm: Unable to stat \"%s\": %s\n", filename,
+              strerror(errno));
+      continue;
+    }
+
+   /*
+    * Process accordingly...
+    */
+
+    if (Verbosity)
+      puts(filename);
+
+    if (S_ISDIR(fileinfo.st_mode))
+    {
+     /*
+      * Directory...
+      */
+
+      if (unlink_directory(filename))
+	goto fail;
+
+      if (rmdir(filename))
+      {
+        fprintf(stderr, "epm: Unable to remove \"%s\": %s\n", filename,
+	        strerror(errno));
+	goto fail;
+      }
+    }
+    else
+    {
+     /*
+      * Regular file or symlink...
+      */
+
+      if (unlink(filename))
+      {
+        fprintf(stderr, "epm: Unable to remove \"%s\": %s\n", filename,
+	        strerror(errno));
+	goto fail;
+      }
+    }
+  }
+
+  closedir(dir);
+  return (0);
+
+  fail:
+
+  closedir(dir);
+  return (-1);
+}
+
+
 /*
  * 'unlink_package()' - Delete a package file.
  */
@@ -323,5 +441,5 @@ unlink_package(const char *ext,		/* I - Package filename extension */
 
 
 /*
- * End of "$Id: file.c 703 2006-08-29 16:43:09Z mike $".
+ * End of "$Id: file.c 841 2010-12-30 20:34:57Z mike $".
  */
