@@ -1,9 +1,9 @@
 /*
- * "$Id: inst.c,v 1.24 2002/10/17 18:13:13 mike Exp $"
+ * "$Id: inst.c 670 2006-04-05 15:08:08Z mike $"
  *
  *   IRIX package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2002 by Easy Software Products.
+ *   Copyright 1999-2006 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
  *
  * Contents:
  *
- *   make_inst() - Make an IRIX software distribution package.
+ *   make_inst()   - Make an IRIX software distribution package.
+ *   inst_subsys() - Write a subsystem definition for the product.
  */
 
 /*
@@ -27,6 +28,15 @@
 #include "epm.h"
 
 
+/*
+ * Local functions...
+ */
+
+void	inst_subsys(FILE *fp, const char *prodname, dist_t *dist,
+		    const char *subpackage, const char *category,
+		    const char *section);
+
+
 /*
  * 'make_inst()' - Make an IRIX software distribution package.
  */
@@ -54,7 +64,6 @@ make_inst(const char     *prodname,	/* I - Product short name */
   char		subsys[255];		/* Subsystem name */
   file_t	*file;			/* Current distribution file */
   command_t	*c;			/* Current command */
-  depend_t	*d;			/* Current dependency */
   struct stat	fileinfo;		/* File information */
   const char	*runlevels;		/* Run levels */
   static const char *extensions[] =	/* INST file extensions */
@@ -66,18 +75,18 @@ make_inst(const char     *prodname,	/* I - Product short name */
 		};
 
 
-  (void)platform; /* Eliminates compiler warning about unused variable */
+  REF(platform);
 
   if (Verbosity)
     puts("Creating inst distribution...");
 
-  if (dist->relnumber)
+  if (dist->release[0])
   {
     if (platname[0])
-      snprintf(name, sizeof(name), "%s-%s-%d-%s", prodname, dist->version, dist->relnumber,
+      snprintf(name, sizeof(name), "%s-%s-%s-%s", prodname, dist->version, dist->release,
               platname);
     else
-      snprintf(name, sizeof(name), "%s-%s-%d", prodname, dist->version, dist->relnumber);
+      snprintf(name, sizeof(name), "%s-%s-%s", prodname, dist->version, dist->release);
   }
   else if (platname[0])
     snprintf(name, sizeof(name), "%s-%s-%s", prodname, dist->version, platname);
@@ -107,64 +116,22 @@ make_inst(const char     *prodname,	/* I - Product short name */
   qprintf(fp, "		id \"%s, Software, %s\"\n", dist->product,
           dist->version);
   fprintf(fp, "		version %d\n", dist->vernumber);
-  fputs("		subsys eoe default\n", fp);
-  qprintf(fp, "			id \"%s, Software, %s\"\n", dist->product,
-          dist->version);
-  fprintf(fp, "			exp \"%s.sw.eoe\"\n", prodname);
 
-  for (i = dist->num_depends, d = dist->depends; i > 0; i --, d ++)
-    if (d->type == DEPEND_REQUIRES)
-      break;
+  inst_subsys(fp, prodname, dist, NULL, "Software", "sw");
+  for (i = 0; i < dist->num_subpackages; i ++)
+    inst_subsys(fp, prodname, dist, dist->subpackages[i], "Software", "sw");
 
-  if (i)
-  {
-    fputs("			prereq\n", fp);
-    fputs("			(\n", fp);
-    for (; i > 0; i --, d ++)
-      if (d->type == DEPEND_REQUIRES)
-      {
-        if (strchr(d->product, '.') != NULL)
-  	  fprintf(fp, "				%s %d %d\n",
-         	  d->product, d->vernumber[0], d->vernumber[1]);
-        else if (d->product[0] != '/')
-  	  fprintf(fp, "				%s.sw.eoe %d %d\n",
-         	  d->product, d->vernumber[0], d->vernumber[1]);
-      }
-    fputs("			)\n", fp);
-  }
-
-  for (i = dist->num_depends, d = dist->depends; i > 0; i --, d ++)
-    if (d->type == DEPEND_REPLACES)
-    {
-      if (strchr(d->product, '.') != NULL)
-        fprintf(fp, "			replaces %s %d %d\n",
-         	d->product, d->vernumber[0], d->vernumber[1]);
-      else if (d->product[0] != '/')
-        fprintf(fp, "			replaces %s.sw.eoe %d %d\n",
-         	d->product, d->vernumber[0], d->vernumber[1]);
-    }
-    else if (d->type == DEPEND_INCOMPAT)
-    {
-      if (strchr(d->product, '.') != NULL)
-        fprintf(fp, "			incompat %s %d %d\n",
-         	d->product, d->vernumber[0], d->vernumber[1]);
-      else if (d->product[0] != '/')
-        fprintf(fp, "			incompat %s.sw.eoe %d %d\n",
-         	d->product, d->vernumber[0], d->vernumber[1]);
-    }
-
-  fputs("		endsubsys\n", fp);
   fputs("	endimage\n", fp);
 
   fputs("	image man\n", fp);
   qprintf(fp, "		id \"%s, Man Pages, %s\"\n", dist->product,
           dist->version);
   fprintf(fp, "		version %d\n", dist->vernumber);
-  fputs("		subsys eoe default\n", fp);
-  qprintf(fp, "			id \"%s, Man Pages, %s\"\n", dist->product,
-          dist->version);
-  fprintf(fp, "			exp \"%s.man.eoe\"\n", prodname);
-  fputs("		endsubsys\n", fp);
+
+  inst_subsys(fp, prodname, dist, NULL, "Man Pages", "man");
+  for (i = 0; i < dist->num_subpackages; i ++)
+    inst_subsys(fp, prodname, dist, dist->subpackages[i], "Man Pages", "man");
+
   fputs("	endimage\n", fp);
 
   fputs("endproduct\n", fp);
@@ -183,10 +150,10 @@ make_inst(const char     *prodname,	/* I - Product short name */
       */
 
       for (runlevels = get_runlevels(dist->files + i, "02");
-           isdigit(*runlevels);
+           isdigit(*runlevels & 255);
 	   runlevels ++)
       {
-	file = add_file(dist);
+	file = add_file(dist, dist->files[i].subpackage);
 	file->type = 'l';
 	file->mode = 0;
 	strcpy(file->user, "root");
@@ -227,7 +194,7 @@ make_inst(const char     *prodname,	/* I - Product short name */
     * Add the preinstall script file to the list...
     */
 
-    file = add_file(dist);
+    file = add_file(dist, NULL);
     file->type = '1';
     file->mode = 0555;
     strcpy(file->user, "root");
@@ -281,7 +248,7 @@ make_inst(const char     *prodname,	/* I - Product short name */
     * Add the postinstall script file to the list...
     */
 
-    file = add_file(dist);
+    file = add_file(dist, NULL);
     file->type = '2';
     file->mode = 0555;
     strcpy(file->user, "root");
@@ -335,7 +302,7 @@ make_inst(const char     *prodname,	/* I - Product short name */
     * Add the preremove script file to the list...
     */
 
-    file = add_file(dist);
+    file = add_file(dist, NULL);
     file->type = '3';
     file->mode = 0555;
     strcpy(file->user, "root");
@@ -391,7 +358,7 @@ make_inst(const char     *prodname,	/* I - Product short name */
     * Add the postremove script file to the list...
     */
 
-    file = add_file(dist);
+    file = add_file(dist, NULL);
     file->type = '4';
     file->mode = 0555;
     strcpy(file->user, "root");
@@ -460,9 +427,11 @@ make_inst(const char     *prodname,	/* I - Product short name */
   {
     if (strstr(file->dst, "/man/") != NULL ||
         strstr(file->dst, "/catman/") != NULL)
-      snprintf(subsys, sizeof(subsys), "%s.man.eoe", prodname);
+      snprintf(subsys, sizeof(subsys), "%s.man.%s", prodname,
+               file->subpackage ? file->subpackage : "eoe");
     else
-      snprintf(subsys, sizeof(subsys), "%s.sw.eoe", prodname);
+      snprintf(subsys, sizeof(subsys), "%s.sw.%s", prodname,
+               file->subpackage ? file->subpackage : "eoe");
 
     switch (tolower(file->type))
     {
@@ -480,7 +449,7 @@ make_inst(const char     *prodname,	/* I - Product short name */
       case '4' :
           qprintf(fp, "f %04o %s %s %s %s %s "
 	              "postop(cp $rbase/%s $rbase/%s.copy) "
-		      "removeop($rbase/%s.copy)\n",
+		      "removeop($rbase/%s.copy; rm -f $rbase/%s.copy)\n",
                   file->mode, file->user, file->group, file->dst + 1,
 		  file->src, subsys, file->dst + 1, file->dst + 1,
 		  file->dst + 1);
@@ -498,9 +467,15 @@ make_inst(const char     *prodname,	/* I - Product short name */
 	          file->user, file->group, file->dst + 1, file->src, subsys);
           break;
       case 'i' :
-          qprintf(fp, "f %04o %s %s %s %s %s exitop($rbase/etc/init.d/%s start) removeop($rbase/etc/init.d/%s stop)\n",
+          qprintf(fp, "f %04o %s %s %s %s %s "
+	              "postop(cp $rbase/etc/init.d/%s $rbase/etc/init.d/%s.copy) "
+	              "exitop($rbase/etc/init.d/%s start) "
+		      "removeop($rbase/etc/init.d/%s.copy stop; rm -f $rbase/etc/init.d/%s.copy)\n",
 	          file->mode, file->user, file->group, file->dst + 1,
-		  file->src, subsys, file->dst + 12, file->dst + 12);
+		  file->src, subsys,
+		  file->dst + 12, file->dst + 12,
+		  file->dst + 12,
+		  file->dst + 12, file->dst + 12);
           break;
       case 'l' :
           qprintf(fp, "l %04o %s %s %s - %s symval(%s)\n", file->mode,
@@ -612,5 +587,120 @@ make_inst(const char     *prodname,	/* I - Product short name */
 
 
 /*
- * End of "$Id: inst.c,v 1.24 2002/10/17 18:13:13 mike Exp $".
+ * 'inst_subsys()' - Write a subsystem definition for the product.
+ */
+
+void
+inst_subsys(FILE       *fp,		/* I - File to write to */
+            const char *prodname,	/* I - Product short name */
+	    dist_t     *dist,		/* I - Distribution */
+	    const char *subpackage,	/* I - Subpackage name or NULL */
+	    const char *category,	/* I - "Software" or "Man Pages" */
+	    const char *section)	/* I - "sw" or "man" */
+{
+  int		i;			/* Looping var */
+  depend_t	*d;			/* Current dependency */
+  const char	*product;		/* Product for dependency */
+  char		selfname[1024];		/* Self product name */
+  char		title[1024];		/* Product description/title */
+
+
+  snprintf(selfname, sizeof(selfname), "%s.%s.eoe", prodname, section);
+
+  if (subpackage)
+  {
+    fprintf(fp, "		subsys %s\n", subpackage);
+
+    for (i = 0; i < dist->num_descriptions; i ++)
+      if (dist->descriptions[i].subpackage == subpackage)
+        break;
+
+    if (i < dist->num_descriptions)
+      snprintf(title, sizeof(title), "%s %s", dist->product,
+               dist->descriptions[i].description);
+    else
+      strlcpy(title, dist->product, sizeof(title));
+  }
+  else
+  {
+    fputs("		subsys eoe default\n", fp);
+
+    strlcpy(title, dist->product, sizeof(title));
+  }
+
+  qprintf(fp, "			id \"%s, %s, %s\"\n", title, category,
+          dist->version);
+  fprintf(fp, "			exp \"%s.%s.%s\"\n", prodname, section,
+          subpackage ? subpackage : "eoe");
+
+  for (i = dist->num_depends, d = dist->depends; i > 0; i --, d ++)
+    if (d->type == DEPEND_REQUIRES && d->subpackage == subpackage)
+      break;
+
+  if (i)
+  {
+    fputs("			prereq\n", fp);
+    fputs("			(\n", fp);
+    for (; i > 0; i --, d ++)
+      if (d->type == DEPEND_REQUIRES && d->subpackage == subpackage)
+      {
+	if (!strcmp(d->product, "_self"))
+          product = selfname;
+	else
+          product = d->product;
+
+        if (strchr(product, '.') != NULL)
+  	  fprintf(fp, "				%s %d %d\n",
+         	  product, d->vernumber[0], d->vernumber[1]);
+        else if (product[0] != '/')
+  	  fprintf(fp, "				%s.%s.* %d %d\n",
+         	  product, section, d->vernumber[0], d->vernumber[1]);
+      }
+    fputs("			)\n", fp);
+  }
+
+  for (i = dist->num_depends, d = dist->depends; i > 0; i --, d ++)
+    if (d->type == DEPEND_REPLACES && d->subpackage == subpackage)
+    {
+      if (!strcmp(d->product, "_self"))
+        product = selfname;
+      else
+        product = d->product;
+
+      if (strchr(product, '.') != NULL)
+      {
+        fprintf(fp, "			replaces %s %d %d\n",
+         	product, d->vernumber[0], d->vernumber[1]);
+        fprintf(fp, "			updates %s %d %d\n",
+         	product, d->vernumber[0], d->vernumber[1]);
+      }
+      else if (product[0] != '/')
+      {
+        fprintf(fp, "			replaces %s.%s.* %d %d\n",
+         	product, section, d->vernumber[0], d->vernumber[1]);
+        fprintf(fp, "			updates %s.%s.* %d %d\n",
+         	product, section, d->vernumber[0], d->vernumber[1]);
+      }
+    }
+    else if (d->type == DEPEND_INCOMPAT && d->subpackage == subpackage)
+    {
+      if (!strcmp(d->product, "_self"))
+        product = selfname;
+      else
+        product = d->product;
+
+      if (strchr(product, '.') != NULL)
+        fprintf(fp, "			incompat %s %d %d\n",
+         	product, d->vernumber[0], d->vernumber[1]);
+      else if (product[0] != '/')
+        fprintf(fp, "			incompat %s.%s.* %d %d\n",
+         	product, section, d->vernumber[0], d->vernumber[1]);
+    }
+
+  fputs("		endsubsys\n", fp);
+}
+
+
+/*
+ * End of "$Id: inst.c 670 2006-04-05 15:08:08Z mike $".
  */
