@@ -1,9 +1,9 @@
 /*
- * "$Id: pkg.c 747 2007-01-06 02:17:15Z mike $"
+ * "$Id: pkg.c 833 2010-12-30 00:00:50Z mike $"
  *
  *   AT&T package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2007 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,7 +53,8 @@ make_pkg(const char     *prodname,	/* I - Product short name */
 		preinstall[1024],	/* Pre install script */
 		postinstall[1024],	/* Post install script */
 		preremove[1024],	/* Pre remove script */
-		postremove[1024];	/* Post remove script */
+		postremove[1024],	/* Post remove script */
+		request[1024];		/* Request script */
   char		current[1024];		/* Current directory */
   file_t	*file;			/* Current distribution file */
   command_t	*c;			/* Current command */
@@ -332,6 +333,47 @@ make_pkg(const char     *prodname,	/* I - Product short name */
   else
     postremove[0] = '\0';
 
+ /*
+  * Write the request file for pkgmk...
+  */
+
+  for (i = dist->num_commands, c = dist->commands; i > 0; i --, c ++)
+    if (c->type == COMMAND_LITERAL && !strcmp(c->section, "request"))
+      break;
+
+  if (i)
+  {
+   /*
+    * Write the request file for pkgmk...
+    */
+
+    if (Verbosity)
+      puts("Creating request script...");
+
+    snprintf(request, sizeof(request), "%s/%s.request", directory,
+             prodname);
+
+    if ((fp = fopen(request, "w")) == NULL)
+    {
+      fprintf(stderr, "epm: Unable to create script file \"%s\" - %s\n",
+              request, strerror(errno));
+      return (1);
+    }
+
+    fchmod(fileno(fp), 0755);
+
+    fputs("#!/bin/sh\n", fp);
+    fputs("# " EPM_VERSION "\n", fp);
+
+    for (; i > 0; i --, c ++)
+      if (c->type == COMMAND_LITERAL && !strcmp(c->section, "request"))
+        fprintf(fp, "%s\n", c->command);
+
+    fclose(fp);
+  }
+  else
+    request[0] = '\0';
+
  /*
   * Add symlinks for init scripts...
   */
@@ -408,6 +450,8 @@ make_pkg(const char     *prodname,	/* I - Product short name */
     fprintf(fp, "i preremove=%s\n", pkg_path(preremove, current));
   if (postremove[0])
     fprintf(fp, "i postremove=%s\n", pkg_path(postremove, current));
+  if (request[0])
+    fprintf(fp, "i request=%s\n", pkg_path(request, current));
 
   for (i = dist->num_files, file = dist->files; i > 0; i --, file ++)
     switch (tolower(file->type))
@@ -487,7 +531,10 @@ make_pkg(const char     *prodname,	/* I - Product short name */
   * Compress the package stream file...
   */
 
-  if (run_command(directory, EPM_GZIP " -v9 %s.pkg", name))
+  snprintf(filename, sizeof(filename), "%s.pkg.gz", name);
+  unlink(filename);
+
+  if (run_command(directory, EPM_GZIP " -vf9 %s.pkg", name))
     return (1);
 
  /*
@@ -513,6 +560,11 @@ make_pkg(const char     *prodname,	/* I - Product short name */
       unlink(preremove);
     if (postremove[0])
       unlink(postremove);
+    if (request[0])
+      unlink(request);
+
+    snprintf(filename, sizeof(filename), "%s/%s", directory, prodname);
+    unlink_directory(filename);
   }
 
   return (0);
@@ -539,5 +591,5 @@ pkg_path(const char *filename,		/* I - Source filename */
 
 
 /*
- * End of "$Id: pkg.c 747 2007-01-06 02:17:15Z mike $".
+ * End of "$Id: pkg.c 833 2010-12-30 00:00:50Z mike $".
  */
