@@ -1,9 +1,9 @@
 /*
- * "$Id: portable.c 670 2006-04-05 15:08:08Z mike $"
+ * "$Id: portable.c 833 2010-12-30 00:00:50Z mike $"
  *
  *   Portable package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2006 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
  * Contents:
  *
  *   make_portable()      - Make a portable software distribution package.
+ *   clean_distfiles()    - Remove temporary software distribution files...
  *   write_combined()     - Write all of the distribution files in tar files.
  *   write_commands()     - Write commands.
  *   write_common()       - Write the common shell script header.
@@ -42,6 +43,9 @@
  * Local functions...
  */
 
+static void	clean_distfiles(const char *directory, const char *prodname,
+		                const char *platname, dist_t *dist,
+				const char *subpackage);
 static int	write_combined(const char *title, const char *directory,
 		               const char *prodname, const char *platname,
 			       dist_t *dist, const char **files,
@@ -160,6 +164,19 @@ make_portable(const char     *prodname,	/* I - Product short name */
                        patchfiles, deftime, setup, types))
       return (1);
 
+ /*
+  * Cleanup...
+  */
+
+  if (!KeepFiles)
+  {
+    clean_distfiles(directory, prodname, platname, dist, NULL);
+
+    for (i = 0; i < dist->num_subpackages; i ++)
+      clean_distfiles(directory, prodname, platname, dist,
+                      dist->subpackages[i]);
+  }
+
  /*
   * Return!
   */
@@ -168,6 +185,66 @@ make_portable(const char     *prodname,	/* I - Product short name */
 }
 
 
+/*
+ * 'clean_distfiles()' - Remove temporary software distribution files...
+ */
+
+static void
+clean_distfiles(const char *directory,	/* I - Directory */
+	        const char *prodname,	/* I - Product name */
+                const char *platname,	/* I - Platform name */
+	        dist_t     *dist,	/* I - Distribution */
+	        const char *subpackage)	/* I - Subpackage */
+{
+  char		prodfull[255],		/* Full name of product */
+		filename[1024];		/* Name of temporary file */
+
+
+ /*
+  * Figure out the full name of the distribution...
+  */
+
+  if (subpackage)
+    snprintf(prodfull, sizeof(prodfull), "%s-%s", prodname, subpackage);
+  else
+    strlcpy(prodfull, prodname, sizeof(prodfull));
+
+ /*
+  * Remove the distribution files...
+  */
+
+  if (Verbosity)
+    printf("Removing %s temporary files...\n", prodfull);
+
+  snprintf(filename, sizeof(filename), "%s/%s.install", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.license", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.patch", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.psw", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.psw", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.readme", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.remove", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.ss", directory, prodfull);
+  unlink(filename);
+
+  snprintf(filename, sizeof(filename), "%s/%s.sw", directory, prodfull);
+  unlink(filename);
+}
+
+
 /*
  * 'write_combined()' - Write all of the distribution files in tar files.
  */
@@ -187,6 +264,9 @@ write_combined(const char *title,	/* I - Title */
   tarf_t	*tarfile;		/* Distribution tar file */
   char		tarfilename[1024],	/* Name of tar file */
 		filename[1024];		/* Name of temporary file */
+#ifdef __APPLE__
+  FILE		*fp;			/* Plist file... */
+#endif /* __APPLE__ */
   struct stat	srcstat;		/* Source file information */
   const char	*destdir;		/* Destination directory */
   const char	*setup_img;		/* Setup image name */
@@ -197,8 +277,8 @@ write_combined(const char *title,	/* I - Title */
   */
 
   if (dist->release[0])
-    snprintf(tarfilename, sizeof(tarfilename), "%s/%s-%s-%s", directory, prodname,
-             dist->version, dist->release);
+    snprintf(tarfilename, sizeof(tarfilename), "%s/%s-%s-%s", directory,
+             prodname, dist->version, dist->release);
   else
     snprintf(tarfilename, sizeof(tarfilename), "%s/%s-%s", directory, prodname,
              dist->version);
@@ -228,8 +308,6 @@ write_combined(const char *title,	/* I - Title */
   if (Verbosity)
     printf("Writing %s archive:\n", title);
 
-  destdir = "";
-
 #ifdef __APPLE__
   if (setup)
   {
@@ -325,7 +403,54 @@ write_combined(const char *title,	/* I - Title */
     if (Verbosity)
       printf("    %7.0fk PkgInfo\n", (srcstat.st_size + 1023) / 1024.0);
 
-    snprintf(filename, sizeof(filename), "%s/setup.plist", DataDir);
+    snprintf(filename, sizeof(filename), "%s/%s.setup.plist", directory,
+             prodname);
+    if ((fp = fopen(filename, "w")) == NULL)
+    {
+      fprintf(stderr, "epm: Error writing %s -\n    %s\n", filename,
+              strerror(errno));
+      tar_close(tarfile);
+      return (-1);
+    }
+
+    fprintf(fp, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+		"<plist version=\"0.9\">\n"
+		"    <dict>\n"
+		"	<key>CFBundleInfoDictionaryVersion</key>\n"
+		"	<string>6.0</string>\n"
+		"	<key>CFBundleExecutable</key>\n"
+		"	<string>setup</string>\n"
+		"	<key>CFBundleIdentifier</key>\n"
+		"	<string>com.easysw.epm.setup</string>\n"
+		"	<key>CFBundleVersion</key>\n"
+		"	<string>%s</string>\n"
+		"	<key>CFBundleDevelopmentRegion</key>\n"
+		"	<string>English</string>\n"
+		"	<key>NSHumanReadableCopyright</key>\n"
+		"	<string>Copyright %s</string>\n"
+		"	<key>CFAppleHelpAnchor</key>\n"
+		"	<string>help</string>\n"
+		"	<key>CFBundleName</key>\n"
+		"	<string>Installer for %s</string>\n"
+		"	<key>CFBundlePackageType</key>\n"
+		"	<string>APPL</string>\n"
+		"	<key>CFBundleSignature</key>\n"
+		"	<string>FLTK</string>\n"
+		"	<key>CFBundleIconFile</key>\n"
+		"	<string>setup.icns</string>\n"
+		"	<key>CFBundleShortVersionString</key>\n"
+		"	<string>%s</string>\n"
+		"	<key>CFBundleGetInfoString</key>\n"
+		"	<string>%s, Copyright %s</string>\n"
+		"    </dict>\n"
+		"</plist>\n",
+            dist->version,
+	    dist->copyright,
+	    dist->product,
+	    dist->version,
+	    dist->version, dist->copyright);
+    fclose(fp);
+
     stat(filename, &srcstat);
 
     if (tar_header(tarfile, TAR_NORMAL, srcstat.st_mode & (~0222),
@@ -346,11 +471,17 @@ write_combined(const char *title,	/* I - Title */
       return (-1);
     }
 
+    if (!KeepFiles)
+      unlink(filename);
+
     if (Verbosity)
       printf("    %7.0fk Info.plist\n", (srcstat.st_size + 1023) / 1024.0);
   }
 
   destdir = "Install.app/Contents/Resources/";
+
+#else /* !__APPLE__ */
+  destdir = "";
 #endif /* __APPLE__ */
 
  /*
@@ -572,7 +703,54 @@ write_combined(const char *title,	/* I - Title */
     if (Verbosity)
       printf("    %7.0fk PkgInfo\n", (srcstat.st_size + 1023) / 1024.0);
 
-    snprintf(filename, sizeof(filename), "%s/uninst.plist", DataDir);
+    snprintf(filename, sizeof(filename), "%s/%s.uninst.plist", directory,
+             prodname);
+    if ((fp = fopen(filename, "w")) == NULL)
+    {
+      fprintf(stderr, "epm: Error writing %s -\n    %s\n", filename,
+              strerror(errno));
+      tar_close(tarfile);
+      return (-1);
+    }
+
+    fprintf(fp, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+		"<plist version=\"0.9\">\n"
+		"    <dict>\n"
+		"	<key>CFBundleInfoDictionaryVersion</key>\n"
+		"	<string>6.0</string>\n"
+		"	<key>CFBundleExecutable</key>\n"
+		"	<string>uninst</string>\n"
+		"	<key>CFBundleIdentifier</key>\n"
+		"	<string>com.easysw.epm.uninst</string>\n"
+		"	<key>CFBundleVersion</key>\n"
+		"	<string>%s</string>\n"
+		"	<key>CFBundleDevelopmentRegion</key>\n"
+		"	<string>English</string>\n"
+		"	<key>NSHumanReadableCopyright</key>\n"
+		"	<string>Copyright %s</string>\n"
+		"	<key>CFAppleHelpAnchor</key>\n"
+		"	<string>help</string>\n"
+		"	<key>CFBundleName</key>\n"
+		"	<string>Uninstaller for %s</string>\n"
+		"	<key>CFBundlePackageType</key>\n"
+		"	<string>APPL</string>\n"
+		"	<key>CFBundleSignature</key>\n"
+		"	<string>FLTK</string>\n"
+		"	<key>CFBundleIconFile</key>\n"
+		"	<string>uninst.icns</string>\n"
+		"	<key>CFBundleShortVersionString</key>\n"
+		"	<string>%s</string>\n"
+		"	<key>CFBundleGetInfoString</key>\n"
+		"	<string>%s, Copyright %s</string>\n"
+		"    </dict>\n"
+		"</plist>\n",
+            dist->version,
+	    dist->copyright,
+	    dist->product,
+	    dist->version,
+	    dist->version, dist->copyright);
+    fclose(fp);
+
     stat(filename, &srcstat);
 
     if (tar_header(tarfile, TAR_NORMAL, srcstat.st_mode & (~0222),
@@ -593,6 +771,9 @@ write_combined(const char *title,	/* I - Title */
       return (-1);
     }
 
+    if (!KeepFiles)
+      unlink(filename);
+
     if (Verbosity)
       printf("    %7.0fk Info.plist\n", (srcstat.st_size + 1023) / 1024.0);
 #endif /* __APPLE__ */
@@ -691,6 +872,61 @@ write_combined(const char *title,	/* I - Title */
            tarfilename);
   }
 
+#ifdef __APPLE__
+  {
+    char	dmgfilename[1024];	/* Disk image filename */
+
+
+   /*
+    * Make a disk image containing the package files...
+    */
+
+    if (dist->release[0])
+      snprintf(filename, sizeof(filename), "%s/%s-%s-%s", directory, prodname,
+	       dist->version, dist->release);
+    else
+      snprintf(filename, sizeof(filename), "%s/%s-%s", directory, prodname,
+	       dist->version);
+
+    if (!strcmp(title, "patch"))
+      strlcat(filename, "-patch", sizeof(filename));
+
+    if (platname[0])
+    {
+      strlcat(filename, "-", sizeof(filename));
+      strlcat(filename, platname, sizeof(filename));
+    }
+
+    snprintf(dmgfilename, sizeof(dmgfilename), "%s.dmg", filename);
+
+    mkdir(filename, 0777);
+
+    if (run_command(filename, "tar xvzf ../%s", strrchr(tarfilename, '/') + 1))
+    {
+      fputs("epm: Unable to create disk image template folder!\n", stderr);
+      return (1);
+    }
+
+    if (run_command(NULL, "hdiutil create -ov -srcfolder %s %s",
+		    filename, dmgfilename))
+    {
+      fputs("epm: Unable to create disk image!\n", stderr);
+      return (1);
+    }
+
+    if (!KeepFiles)
+      unlink_directory(filename);
+
+    if (Verbosity)
+    {
+      stat(dmgfilename, &srcstat);
+
+      printf("    %7.0fk %s\n", (srcstat.st_size + 1023) / 1024.0,
+	     dmgfilename);
+    }
+  }
+#endif /* __APPLE__ */
+
   return (0);
 }
 
@@ -753,6 +989,9 @@ write_common(dist_t     *dist,		/* I - Distribution */
 {
   int	i;				/* Looping var */
   FILE	*fp;				/* File pointer */
+  char	line[1024],			/* Line buffer */
+	*start,				/* Start of line */
+	*ptr;				/* Pointer into line */
 
 
  /*
@@ -791,7 +1030,13 @@ write_common(dist_t     *dist,		/* I - Distribution */
 	break;
 
     if (i < dist->num_descriptions)
-      fprintf(fp, " - %s", dist->descriptions[i].description);
+    {
+      strlcpy(line, dist->descriptions[i].description, sizeof(line));
+      if ((ptr = strchr(line, '\n')) != NULL)
+        *ptr = '\0';
+
+      fprintf(fp, " - %s", line);
+    }
   }
   fputs("\n", fp);
   fprintf(fp, "#%%vendor %s\n", dist->vendor);
@@ -810,7 +1055,17 @@ write_common(dist_t     *dist,		/* I - Distribution */
 
     for (; i < dist->num_descriptions; i ++)
       if (dist->descriptions[i].subpackage == subpackage)
-	fprintf(fp, "#%%description %s\n", dist->descriptions[i].description);
+      {
+        strlcpy(line, dist->descriptions[i].description, sizeof(line));
+
+        for (start = line; start; start = ptr)
+	{
+	  if ((ptr = strchr(start, '\n')) != NULL)
+            *ptr++ = '\0';
+
+	  fprintf(fp, "#%%description %s\n", start);
+	}
+      }
   }
   else
   {
@@ -820,7 +1075,17 @@ write_common(dist_t     *dist,		/* I - Distribution */
 
     for (i = 0; i < dist->num_descriptions; i ++)
       if (dist->descriptions[i].subpackage == NULL)
-	fprintf(fp, "#%%description %s\n", dist->descriptions[i].description);
+      {
+        strlcpy(line, dist->descriptions[i].description, sizeof(line));
+
+        for (start = line; start; start = ptr)
+	{
+	  if ((ptr = strchr(start, '\n')) != NULL)
+            *ptr++ = '\0';
+
+	  fprintf(fp, "#%%description %s\n", start);
+	}
+      }
   }
 
   fprintf(fp, "#%%rootsize %d\n", rootsize);
@@ -2696,5 +2961,5 @@ write_space_checks(const char *prodname,/* I - Distribution name */
 
 
 /*
- * End of "$Id: portable.c 670 2006-04-05 15:08:08Z mike $".
+ * End of "$Id: portable.c 833 2010-12-30 00:00:50Z mike $".
  */
