@@ -1,9 +1,9 @@
 /*
- * "$Id: rpm.c 737 2006-12-05 16:09:59Z mike $"
+ * "$Id: rpm.c 840 2010-12-30 20:30:03Z mike $"
  *
  *   Red Hat package gateway for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2006 by Easy Software Products.
+ *   Copyright 1999-2010 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -38,8 +38,8 @@ static int	move_rpms(const char *prodname, const char *directory,
 			  struct utsname *platform,
 			  const char *rpmdir, const char *subpackage,
 			  const char *release);
-static int	write_spec(const char *prodname, dist_t *dist, FILE *fp,
-		           const char *subpackage);
+static int	write_spec(int format, const char *prodname, dist_t *dist,
+		           FILE *fp, const char *subpackage);
 
 
 /*
@@ -47,7 +47,8 @@ static int	write_spec(const char *prodname, dist_t *dist, FILE *fp,
  */
 
 int					/* O - 0 = success, 1 = fail */
-make_rpm(const char     *prodname,	/* I - Product short name */
+make_rpm(int            format,		/* I - Subformat */
+         const char     *prodname,	/* I - Product short name */
          const char     *directory,	/* I - Directory for distribution files */
          const char     *platname,	/* I - Platform name */
          dist_t         *dist,		/* I - Distribution information */
@@ -62,11 +63,10 @@ make_rpm(const char     *prodname,	/* I - Product short name */
   char		name[1024],		/* Product filename */
 		filename[1024];		/* Destination filename */
   file_t	*file;			/* Current distribution file */
-  struct passwd	*pwd;			/* Pointer to user record */
-  struct group	*grp;			/* Pointer to group record */
   char		absdir[1024];		/* Absolute directory */
   char		rpmdir[1024];		/* RPMDIR env var */
   char		release[256];		/* Release: number */
+  const char	*build_option;		/* Additional rpmbuild option */
 
 
   if (Verbosity)
@@ -113,7 +113,9 @@ make_rpm(const char     *prodname,	/* I - Product short name */
   fprintf(fp, "License: %s\n", dist->copyright);
   fprintf(fp, "Packager: %s\n", dist->packager);
   fprintf(fp, "Vendor: %s\n", dist->vendor);
-  fprintf(fp, "BuildRoot: %s/buildroot\n", absdir);
+
+  if (format == PACKAGE_LSB || format == PACKAGE_LSB_SIGNED)
+    fputs("Requires: lsb >= 3.0\n", fp);
 
  /*
   * Tell RPM to put the distributions in the output directory...
@@ -154,9 +156,9 @@ make_rpm(const char     *prodname,	/* I - Product short name */
   * Now list all of the subpackages...
   */
 
-  write_spec(prodname, dist, fp, NULL);
+  write_spec(format, prodname, dist, fp, NULL);
   for (i = 0; i < dist->num_subpackages; i ++)
-    write_spec(prodname, dist, fp, dist->subpackages[i]);
+    write_spec(format, prodname, dist, fp, dist->subpackages[i]);
 
  /*
   * Close the spec file...
@@ -173,16 +175,6 @@ make_rpm(const char     *prodname,	/* I - Product short name */
 
   for (i = dist->num_files, file = dist->files; i > 0; i --, file ++)
   {
-   /*
-    * Find the username and groupname IDs...
-    */
-
-    pwd = getpwnam(file->user);
-    grp = getgrnam(file->group);
-
-    endpwent();
-    endgrent();
-
    /*
     * Copy the file or make the directory or make the symlink as needed...
     */
@@ -196,19 +188,21 @@ make_rpm(const char     *prodname,	/* I - Product short name */
 	  if (Verbosity > 1)
 	    printf("%s -> %s...\n", file->src, filename);
 
-	  if (copy_file(filename, file->src, file->mode, pwd ? pwd->pw_uid : 0,
-			grp ? grp->gr_gid : 0))
+	  if (copy_file(filename, file->src, 0, -1, -1))
 	    return (1);
           break;
       case 'i' :
-          snprintf(filename, sizeof(filename), "%s/buildroot%s/init.d/%s",
-	           directory, SoftwareDir, file->dst);
+          if (format == PACKAGE_LSB || format == PACKAGE_LSB_SIGNED)
+	    snprintf(filename, sizeof(filename), "%s/buildroot/etc/init.d/%s",
+		     directory, file->dst);
+          else
+	    snprintf(filename, sizeof(filename), "%s/buildroot%s/init.d/%s",
+		     directory, SoftwareDir, file->dst);
 
 	  if (Verbosity > 1)
 	    printf("%s -> %s...\n", file->src, filename);
 
-	  if (copy_file(filename, file->src, file->mode, pwd ? pwd->pw_uid : 0,
-			grp ? grp->gr_gid : 0))
+	  if (copy_file(filename, file->src, 0, -1, -1))
 	    return (1);
           break;
       case 'd' :
@@ -217,8 +211,7 @@ make_rpm(const char     *prodname,	/* I - Product short name */
 	  if (Verbosity > 1)
 	    printf("Directory %s...\n", filename);
 
-          make_directory(filename, file->mode, pwd ? pwd->pw_uid : 0,
-			 grp ? grp->gr_gid : 0);
+          make_directory(filename, 0755, -1, -1);
           break;
       case 'l' :
           snprintf(filename, sizeof(filename), "%s/buildroot%s", directory, file->dst);
@@ -238,20 +231,28 @@ make_rpm(const char     *prodname,	/* I - Product short name */
   if (Verbosity)
     puts("Building RPM binary distribution...");
 
+  if (format == PACKAGE_LSB_SIGNED || format == PACKAGE_RPM_SIGNED)
+    build_option = "-signed ";
+  else
+    build_option = "";
+
   if (!strcmp(platform->machine, "intel"))
   {
-    if (run_command(NULL, EPM_RPMBUILD " -bb " EPM_RPMARCH "i386 %s",
-                    specname))
+    if (run_command(NULL, EPM_RPMBUILD " -bb --buildroot \"%s/buildroot\" "
+                          EPM_RPMARCH "i386 %s%s", absdir, build_option,
+			  specname))
       return (1);
   }
   else if (!strcmp(platform->machine, "ppc"))
   {
-    if (run_command(NULL, EPM_RPMBUILD " -bb " EPM_RPMARCH "powerpc %s",
-                    specname))
+    if (run_command(NULL, EPM_RPMBUILD " -bb --buildroot \"%s/buildroot\" "
+                          EPM_RPMARCH "powerpc %s%s", absdir, build_option,
+			  specname))
       return (1);
   }
-  else if (run_command(NULL, EPM_RPMBUILD " -bb " EPM_RPMARCH "%s %s",
-                       platform->machine, specname))
+  else if (run_command(NULL, EPM_RPMBUILD " -bb --buildroot \"%s/buildroot\" "
+                       EPM_RPMARCH "%s %s%s", absdir, platform->machine,
+		       build_option, specname))
     return (1);
 
  /*
@@ -464,9 +465,14 @@ make_rpm(const char     *prodname,	/* I - Product short name */
     if (Verbosity)
       puts("Removing temporary distribution files...");
 
-    run_command(NULL, "/bin/rm -rf %s/RPMS", directory);
-    run_command(NULL, "/bin/rm -f %s/rpms", directory);
-    run_command(NULL, "/bin/rm -rf %s/buildroot", directory);
+    snprintf(filename, sizeof(filename), "%s/RPMS", directory);
+    unlink_directory(filename);
+
+    snprintf(filename, sizeof(filename), "%s/rpms", directory);
+    unlink(filename);
+
+    snprintf(filename, sizeof(filename), "%s/buildroot", directory);
+    unlink_directory(filename);
 
     unlink(specname);
 
@@ -561,7 +567,8 @@ move_rpms(const char     *prodname,	/* I - Product short name */
  */
 
 static int				/* O - 0 on success, -1 on error */
-write_spec(const char *prodname,	/* I - Product name */
+write_spec(int        format,		/* I - Subformat */
+           const char *prodname,	/* I - Product name */
 	   dist_t     *dist,		/* I - Distribution */
            FILE       *fp,		/* I - Spec file */
            const char *subpackage)	/* I - Subpackage name */
@@ -636,6 +643,8 @@ write_spec(const char *prodname,	/* I - Product name */
       fprintf(fp, "Requires: %s", product);
     else if (d->type == DEPEND_PROVIDES)
       fprintf(fp, "Provides: %s", product);
+    else if (d->type == DEPEND_REPLACES)
+      fprintf(fp, "Obsoletes: %s", product);
     else
       fprintf(fp, "Conflicts: %s", product);
 
@@ -691,6 +700,19 @@ write_spec(const char *prodname,	/* I - Product name */
   else
     have_commands = 0;
 
+  for (i = dist->num_commands, c = dist->commands; i > 0; i --, c ++)
+    if (c->type == COMMAND_LITERAL && c->subpackage == subpackage &&
+        !strcmp(c->section, "spec"))
+      break;
+
+  if (i > 0)
+  {
+    for (; i > 0; i --, c ++)
+      if (c->type == COMMAND_LITERAL && c->subpackage == subpackage &&
+	  !strcmp(c->section, "spec"))
+	fprintf(fp, "%s\n", c->command);
+  }
+
   for (i = dist->num_files, file = dist->files; i > 0; i --, file ++)
     if (tolower(file->type) == 'i' && file->subpackage == subpackage)
       break;
@@ -703,57 +725,74 @@ write_spec(const char *prodname,	/* I - Product name */
     fputs("if test \"x$1\" = x1; then\n", fp);
     fputs("	echo Setting up init scripts...\n", fp);
 
-   /*
-    * Find where the frigging init scripts go...
-    */
+    if (format == PACKAGE_LSB)
+    {
+     /*
+      * Use LSB commands to install the init scripts...
+      */
 
-    fputs("	rcdir=\"\"\n", fp);
-    fputs("	for dir in /sbin/rc.d /sbin /etc/rc.d /etc ; do\n", fp);
-    fputs("		if test -d $dir/rc3.d -o -h $dir/rc3.d; then\n", fp);
-    fputs("			rcdir=\"$dir\"\n", fp);
-    fputs("		fi\n", fp);
-    fputs("	done\n", fp);
-    fputs("	if test \"$rcdir\" = \"\" ; then\n", fp);
-    fputs("		echo Unable to determine location of startup scripts!\n", fp);
-    fputs("	else\n", fp);
-    for (; i > 0; i --, file ++)
-      if (tolower(file->type) == 'i' && file->subpackage == subpackage)
-      {
-	fputs("		if test -d $rcdir/init.d; then\n", fp);
-	qprintf(fp, "			/bin/rm -f $rcdir/init.d/%s\n", file->dst);
-	qprintf(fp, "			/bin/ln -s %s/init.d/%s "
-                    "$rcdir/init.d/%s\n", SoftwareDir, file->dst, file->dst);
-	fputs("		else\n", fp);
-	fputs("			if test -d /etc/init.d; then\n", fp);
-	qprintf(fp, "				/bin/rm -f /etc/init.d/%s\n", file->dst);
-	qprintf(fp, "				/bin/ln -s %s/init.d/%s "
-                    "/etc/init.d/%s\n", SoftwareDir, file->dst, file->dst);
-	fputs("			fi\n", fp);
-	fputs("		fi\n", fp);
-
-	for (runlevels = get_runlevels(dist->files + i, "0123456");
-             isdigit(*runlevels & 255);
-	     runlevels ++)
+      for (; i > 0; i --, file ++)
+	if (tolower(file->type) == 'i' && file->subpackage == subpackage)
 	{
-	  if (*runlevels == '0')
-            number = get_stop(file, 0);
-	  else
-	    number = get_start(file, 99);
+	  fprintf(fp, "	/usr/lib/lsb/install_initd /etc/init.d/%s\n", file->dst);
+	  fprintf(fp, "	/etc/init.d/%s start\n", file->dst);
+	}
+    }
+    else
+    {
+     /*
+      * Find where the frigging init scripts go...
+      */
 
-	  qprintf(fp, "		/bin/rm -f $rcdir/rc%c.d/%c%02d%s\n", *runlevels,
-	          (*runlevels == '0' || *runlevels == '1' ||
-		   *runlevels == '6') ? 'K' : 'S', number, file->dst);
-	  qprintf(fp, "		/bin/ln -s %s/init.d/%s "
-                      "$rcdir/rc%c.d/%c%02d%s\n", SoftwareDir, file->dst,
-		  *runlevels,
-		  (*runlevels == '0' || *runlevels == '1' ||
-		   *runlevels == '6') ? 'K' : 'S', number, file->dst);
-        }
+      fputs("	rcdir=\"\"\n", fp);
+      fputs("	for dir in /sbin/rc.d /sbin /etc/rc.d /etc ; do\n", fp);
+      fputs("		if test -d $dir/rc3.d -o -h $dir/rc3.d; then\n", fp);
+      fputs("			rcdir=\"$dir\"\n", fp);
+      fputs("		fi\n", fp);
+      fputs("	done\n", fp);
+      fputs("	if test \"$rcdir\" = \"\" ; then\n", fp);
+      fputs("		echo Unable to determine location of startup scripts!\n", fp);
+      fputs("	else\n", fp);
+      for (; i > 0; i --, file ++)
+	if (tolower(file->type) == 'i' && file->subpackage == subpackage)
+	{
+	  fputs("		if test -d $rcdir/init.d; then\n", fp);
+	  qprintf(fp, "			/bin/rm -f $rcdir/init.d/%s\n", file->dst);
+	  qprintf(fp, "			/bin/ln -s %s/init.d/%s "
+		      "$rcdir/init.d/%s\n", SoftwareDir, file->dst, file->dst);
+	  fputs("		else\n", fp);
+	  fputs("			if test -d /etc/init.d; then\n", fp);
+	  qprintf(fp, "				/bin/rm -f /etc/init.d/%s\n", file->dst);
+	  qprintf(fp, "				/bin/ln -s %s/init.d/%s "
+		      "/etc/init.d/%s\n", SoftwareDir, file->dst, file->dst);
+	  fputs("			fi\n", fp);
+	  fputs("		fi\n", fp);
 
-        qprintf(fp, "		%s/init.d/%s start\n", SoftwareDir, file->dst);
-      }
+	  for (runlevels = get_runlevels(dist->files + i, "0123456");
+	       isdigit(*runlevels & 255);
+	       runlevels ++)
+	  {
+	    if (*runlevels == '0')
+	      number = get_stop(file, 0);
+	    else
+	      number = get_start(file, 99);
+
+	    qprintf(fp, "		/bin/rm -f $rcdir/rc%c.d/%c%02d%s\n", *runlevels,
+		    (*runlevels == '0' || *runlevels == '1' ||
+		     *runlevels == '6') ? 'K' : 'S', number, file->dst);
+	    qprintf(fp, "		/bin/ln -s %s/init.d/%s "
+			"$rcdir/rc%c.d/%c%02d%s\n", SoftwareDir, file->dst,
+		    *runlevels,
+		    (*runlevels == '0' || *runlevels == '1' ||
+		     *runlevels == '6') ? 'K' : 'S', number, file->dst);
+	  }
+
+	  qprintf(fp, "		%s/init.d/%s start\n", SoftwareDir, file->dst);
+	}
+
+      fputs("	fi\n", fp);
+    }
 
-    fputs("	fi\n", fp);
     fputs("fi\n", fp);
   }
 
@@ -769,48 +808,65 @@ write_spec(const char *prodname,	/* I - Product name */
     fputs("if test \"x$1\" = x0; then\n", fp);
     fputs("	echo Cleaning up init scripts...\n", fp);
 
-   /*
-    * Find where the frigging init scripts go...
-    */
+    if (format == PACKAGE_LSB)
+    {
+     /*
+      * Use LSB commands to remove the init scripts...
+      */
 
-    fputs("	rcdir=\"\"\n", fp);
-    fputs("	for dir in /sbin/rc.d /sbin /etc/rc.d /etc ; do\n", fp);
-    fputs("		if test -d $dir/rc3.d -o -h $dir/rc3.d; then\n", fp);
-    fputs("			rcdir=\"$dir\"\n", fp);
-    fputs("		fi\n", fp);
-    fputs("	done\n", fp);
-    fputs("	if test \"$rcdir\" = \"\" ; then\n", fp);
-    fputs("		echo Unable to determine location of startup scripts!\n", fp);
-    fputs("	else\n", fp);
-    for (; i > 0; i --, file ++)
-      if (tolower(file->type) == 'i' && file->subpackage == subpackage)
-      {
-        qprintf(fp, "		%s/init.d/%s stop\n", SoftwareDir, file->dst);
-
-	fputs("		if test -d $rcdir/init.d; then\n", fp);
-	qprintf(fp, "			/bin/rm -f $rcdir/init.d/%s\n", file->dst);
-	fputs("		else\n", fp);
-	fputs("			if test -d /etc/init.d; then\n", fp);
-	qprintf(fp, "				/bin/rm -f /etc/init.d/%s\n", file->dst);
-	fputs("			fi\n", fp);
-	fputs("		fi\n", fp);
-
-	for (runlevels = get_runlevels(dist->files + i, "0123456");
-             isdigit(*runlevels & 255);
-	     runlevels ++)
+      for (; i > 0; i --, file ++)
+	if (tolower(file->type) == 'i' && file->subpackage == subpackage)
 	{
-	  if (*runlevels == '0')
-            number = get_stop(file, 0);
-	  else
-	    number = get_start(file, 99);
+	  fprintf(fp, "	/etc/init.d/%s stop\n", file->dst);
+	  fprintf(fp, "	/usr/lib/lsb/remove_initd /etc/init.d/%s\n", file->dst);
+	}
+    }
+    else
+    {
+     /*
+      * Find where the frigging init scripts go...
+      */
 
-	  qprintf(fp, "		/bin/rm -f $rcdir/rc%c.d/%c%02d%s\n", *runlevels,
-	          (*runlevels == '0' || *runlevels == '1' ||
-		   *runlevels == '6') ? 'K' : 'S', number, file->dst);
-        }
-      }
+      fputs("	rcdir=\"\"\n", fp);
+      fputs("	for dir in /sbin/rc.d /sbin /etc/rc.d /etc ; do\n", fp);
+      fputs("		if test -d $dir/rc3.d -o -h $dir/rc3.d; then\n", fp);
+      fputs("			rcdir=\"$dir\"\n", fp);
+      fputs("		fi\n", fp);
+      fputs("	done\n", fp);
+      fputs("	if test \"$rcdir\" = \"\" ; then\n", fp);
+      fputs("		echo Unable to determine location of startup scripts!\n", fp);
+      fputs("	else\n", fp);
+      for (; i > 0; i --, file ++)
+	if (tolower(file->type) == 'i' && file->subpackage == subpackage)
+	{
+	  qprintf(fp, "		%s/init.d/%s stop\n", SoftwareDir, file->dst);
+
+	  fputs("		if test -d $rcdir/init.d; then\n", fp);
+	  qprintf(fp, "			/bin/rm -f $rcdir/init.d/%s\n", file->dst);
+	  fputs("		else\n", fp);
+	  fputs("			if test -d /etc/init.d; then\n", fp);
+	  qprintf(fp, "				/bin/rm -f /etc/init.d/%s\n", file->dst);
+	  fputs("			fi\n", fp);
+	  fputs("		fi\n", fp);
+
+	  for (runlevels = get_runlevels(dist->files + i, "0123456");
+	       isdigit(*runlevels & 255);
+	       runlevels ++)
+	  {
+	    if (*runlevels == '0')
+	      number = get_stop(file, 0);
+	    else
+	      number = get_start(file, 99);
+
+	    qprintf(fp, "		/bin/rm -f $rcdir/rc%c.d/%c%02d%s\n", *runlevels,
+		    (*runlevels == '0' || *runlevels == '1' ||
+		     *runlevels == '6') ? 'K' : 'S', number, file->dst);
+	  }
+	}
+
+      fputs("	fi\n", fp);
+    }
 
-    fputs("	fi\n", fp);
     fputs("fi\n", fp);
   }
   else
@@ -882,8 +938,12 @@ write_spec(const char *prodname,	/* I - Product name */
 	            file->group, file->dst);
             break;
 	case 'i' :
-            fprintf(fp, "%%attr(0555,root,root) \"%s/init.d/%s\"\n", SoftwareDir,
-	            file->dst);
+	    if (format == PACKAGE_LSB)
+	      fprintf(fp, "%%attr(0555,root,root) \"/etc/init.d/%s\"\n",
+		      file->dst);
+            else
+	      fprintf(fp, "%%attr(0555,root,root) \"%s/init.d/%s\"\n",
+	              SoftwareDir, file->dst);
             break;
       }
 
@@ -892,5 +952,5 @@ write_spec(const char *prodname,	/* I - Product name */
 
 
 /*
- * End of "$Id: rpm.c 737 2006-12-05 16:09:59Z mike $".
+ * End of "$Id: rpm.c 840 2010-12-30 20:30:03Z mike $".
  */
