@@ -1,9 +1,9 @@
 /*
- * "$Id: run.c,v 1.2 2002/01/02 20:39:40 mike Exp $"
+ * "$Id: run.c 611 2005-01-11 21:37:42Z mike $"
  *
  *   External program function for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2002 by Easy Software Products.
+ *   Copyright 1999-2005 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -67,11 +67,11 @@ run_command(const char *directory,	/* I - Directory for command or NULL */
   argv[0] = argbuf;
 
   for (argptr = argbuf, argc = 1; *argptr != '\0' && argc < 99; argptr ++)
-    if (isspace(*argptr))
+    if (isspace(*argptr & 255))
     {
       *argptr++ = '\0';
 
-      while (isspace(*argptr))
+      while (isspace(*argptr & 255))
         argptr ++;
 
       if (*argptr != '\0')
@@ -124,7 +124,7 @@ run_command(const char *directory,	/* I - Directory for command or NULL */
     * if !Verbosity...
     */
 
-    if (!Verbosity)
+    if (Verbosity < 2)
     {
       close(0);
       close(1);
@@ -147,7 +147,8 @@ run_command(const char *directory,	/* I - Directory for command or NULL */
     */
 
     execvp(argv[0], argv);
-    perror("epm: execvp failed");
+    fprintf(stderr, "epm: Unable to execute \"%s\" program: %s\n", argv[0],
+            strerror(errno));
     exit(errno);
   }
   else if (pid < 0)
@@ -177,5 +178,5 @@ run_command(const char *directory,	/* I - Directory for command or NULL */
 
 
 /*
- * End of "$Id: run.c,v 1.2 2002/01/02 20:39:40 mike Exp $".
+ * End of "$Id: run.c 611 2005-01-11 21:37:42Z mike $".
  */
