@@ -1,9 +1,9 @@
 /*
- * "$Id: snprintf.c,v 1.3 2002/08/30 02:00:43 mike Exp $"
+ * "$Id: snprintf.c 611 2005-01-11 21:37:42Z mike $"
  *
  *   snprintf functions for the ESP Package Manager (EPM).
  *
- *   Copyright 1999-2002 by Easy Software Products.
+ *   Copyright 1999-2005 by Easy Software Products.
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -17,8 +17,8 @@
  *
  * Contents:
  *
- *   vsnprintf() - Format a string into a fixed size buffer.
- *   snprintf()  - Format a string into a fixed size buffer.
+ *   epm_vsnprintf() - Format a string into a fixed size buffer.
+ *   epm_snprintf()  - Format a string into a fixed size buffer.
  */
 
 /*
@@ -35,25 +35,24 @@
  * 'vsnprintf()' - Format a string into a fixed size buffer.
  */
 
-int				/* O - Number of bytes formatted */
-vsnprintf(char       *buffer,	/* O - Output buffer */
-          size_t     bufsize,	/* O - Size of output buffer */
-	  const char *format,	/* I - printf-style format string */
-	  va_list    ap)	/* I - Pointer to additional arguments */
+int					/* O - Number of bytes formatted */
+epm_vsnprintf(char       *buffer,	/* O - Output buffer */
+              size_t     bufsize,	/* O - Size of output buffer */
+	      const char *format,	/* I - printf-style format string */
+ 	      va_list    ap)		/* I - Pointer to additional arguments */
 {
-  char		*bufptr,	/* Pointer to position in buffer */
-		*bufend,	/* Pointer to end of buffer */
-		sign,		/* Sign of format width */
-		size,		/* Size character (h, l, L) */
-		type;		/* Format type character */
-  const char	*bufformat;	/* Start of format */
-  int		width,		/* Width of field */
-		prec;		/* Number of characters of precision */
-  char		tformat[100],	/* Temporary format string for sprintf() */
-		temp[1024];	/* Buffer for formatted numbers */
-  int		*chars;		/* Pointer to integer for %p */
-  char		*s;		/* Pointer to string */
-  int		slen;		/* Length of string */
+  char		*bufptr,		/* Pointer to position in buffer */
+		*bufend,		/* Pointer to end of buffer */
+		sign,			/* Sign of format width */
+		size,			/* Size character (h, l, L) */
+		type;			/* Format type character */
+  const char	*bufformat;		/* Start of format */
+  int		width,			/* Width of field */
+		prec;			/* Number of characters of precision */
+  char		tformat[100],		/* Temporary format string for sprintf() */
+		temp[1024];		/* Buffer for formatted numbers */
+  char		*s;			/* Pointer to string */
+  int		slen;			/* Length of string */
 
 
  /*
@@ -119,8 +118,7 @@ vsnprintf(char       *buffer,	/* O - Output buffer */
 	        (width + 2) > sizeof(temp))
 	      break;
 
-	    strncpy(tformat, bufformat, format - bufformat);
-	    tformat[format - bufformat] = '\0';
+	    strlcpy(tformat, bufformat, format - bufformat + 1);
 
 	    sprintf(temp, tformat, va_arg(ap, double));
 
@@ -149,8 +147,7 @@ vsnprintf(char       *buffer,	/* O - Output buffer */
 	        (width + 2) > sizeof(temp))
 	      break;
 
-	    strncpy(tformat, bufformat, format - bufformat);
-	    tformat[format - bufformat] = '\0';
+	    strlcpy(tformat, bufformat, format - bufformat + 1);
 
 	    sprintf(temp, tformat, va_arg(ap, int));
 
@@ -172,22 +169,12 @@ vsnprintf(char       *buffer,	/* O - Output buffer */
 	        (width + 2) > sizeof(temp))
 	      break;
 
-	    strncpy(tformat, bufformat, format - bufformat);
-	    tformat[format - bufformat] = '\0';
+	    strlcpy(tformat, bufformat, format - bufformat + 1);
 
 	    sprintf(temp, tformat, va_arg(ap, void *));
 
-	    if ((bufptr + strlen(temp)) > bufend)
-	    {
-	      strncpy(bufptr, temp, bufend - bufptr);
-	      bufptr = bufend;
-	      break;
-	    }
-	    else
-	    {
-	      strcpy(bufptr, temp);
-	      bufptr += strlen(temp);
-	    }
+	    strlcpy(bufptr, temp, bufend - bufptr + 1);
+	    bufptr += strlen(bufptr);
 	    break;
 
         case 'c' : /* Character or character array */
@@ -236,22 +223,12 @@ vsnprintf(char       *buffer,	/* O - Output buffer */
 	        (width + 2) > sizeof(temp))
 	      break;
 
-	    strncpy(tformat, bufformat, format - bufformat);
-	    tformat[format - bufformat] = '\0';
+	    strlcpy(tformat, bufformat, format - bufformat + 1);
 
 	    sprintf(temp, tformat, va_arg(ap, int));
 
-	    if ((bufptr + strlen(temp)) > bufend)
-	    {
-	      strncpy(bufptr, temp, bufend - bufptr);
-	      bufptr = bufend;
-	      break;
-	    }
-	    else
-	    {
-	      strcpy(bufptr, temp);
-	      bufptr += strlen(temp);
-	    }
+	    strlcpy(bufptr, temp, bufend - bufptr + 1);
+	    bufptr += strlen(bufptr);
 	    break;
       }
     }
@@ -271,17 +248,17 @@ vsnprintf(char       *buffer,	/* O - Output buffer */
 
 #ifndef HAVE_SNPRINTF
 /*
- * 'snprintf()' - Format a string into a fixed size buffer.
+ * 'epm_snprintf()' - Format a string into a fixed size buffer.
  */
 
-int				/* O - Number of bytes formatted */
-snprintf(char       *buffer,	/* O - Output buffer */
-         size_t     bufsize,	/* O - Size of output buffer */
-         const char *format,	/* I - printf-style format string */
-	 ...)			/* I - Additional arguments as needed */
+int					/* O - Number of bytes formatted */
+epm_snprintf(char       *buffer,	/* O - Output buffer */
+             size_t     bufsize,	/* O - Size of output buffer */
+             const char *format,	/* I - printf-style format string */
+	     ...)			/* I - Additional arguments as needed */
 {
-  int		bytes;		/* Number of bytes formatted */
-  va_list 	ap;		/* Pointer to additional arguments */
+  int		bytes;			/* Number of bytes formatted */
+  va_list 	ap;			/* Pointer to additional arguments */
 
 
   va_start(ap, format);
@@ -294,6 +271,6 @@ snprintf(char       *buffer,	/* O - Output buffer */
 
 
 /*
- * End of "$Id: snprintf.c,v 1.3 2002/08/30 02:00:43 mike Exp $".
+ * End of "$Id: snprintf.c 611 2005-01-11 21:37:42Z mike $".
  */
 
