@@ -1,9 +1,9 @@
 //
-// "$Id: uninst2.cxx 739 2006-12-05 17:20:27Z mike $"
+// "$Id: uninst2.cxx 834 2010-12-30 00:08:36Z mike $"
 //
 //   ESP Software Removal Wizard main entry for the ESP Package Manager (EPM).
 //
-//   Copyright 1999-2006 by Easy Software Products.
+//   Copyright 1999-2010 by Easy Software Products.
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License as published by
@@ -511,7 +511,7 @@ remove_dist(const gui_dist_t *dist)	// I - Distribution to remove
 #ifdef __APPLE__
   // Run the remove script using Apple's authorization API...
   FILE		*fp = NULL;
-  char		*args[2] = { "now", NULL };
+  char		*args[2] = { (char *)"now", NULL };
   OSStatus	astatus;
 
 
@@ -737,5 +737,5 @@ update_sizes(void)
 
 
 //
-// End of "$Id: uninst2.cxx 739 2006-12-05 17:20:27Z mike $".
+// End of "$Id: uninst2.cxx 834 2010-12-30 00:08:36Z mike $".
 //
